@@ -13,9 +13,23 @@
 #    under the License.
 
 from django.forms import ValidationError  # noqa
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 
+html_escape_table = {
+    "&": "&amp;",
+    '"': "&quot;",
+    "'": "&apos;",
+    ">": "&gt;",
+    "<": "&lt;",
+}
+
+
+def html_escape(text):
+    return ''.join(html_escape_table.get(s, s) for s in text)
+
+
 def parse_str_meta(meta_s):
     """Parse multiline string with data from form.
 
@@ -32,7 +46,7 @@ def parse_str_meta(meta_s):
             # Key for unsetting
             key = string.strip('\"\'\ ')
             if len(key) not in range(1, 256):
-                msg = _("Key '%s' has inproper length.") % key
+                msg = _("Key '%s' has improper length.") % key
             elif " " in key:
                 msg = _("Key can not contain spaces. See string '%s'.") % key
             elif key not in unset_list:
@@ -58,14 +72,12 @@ def parse_str_meta(meta_s):
     return set_dict, unset_list
 
 
-def metadata_to_str(metadata):
+def metadata_to_str(metadata, meta_visible_limit=4, text_length_limit=25):
 
     # Only convert dictionaries
     if not hasattr(metadata, 'keys'):
         return metadata
 
-    meta_visible_limit = 4
-    text_length_limit = 25
     meta = []
     meta_keys = metadata.keys()
     meta_keys.sort()
@@ -77,11 +89,11 @@ def metadata_to_str(metadata):
         v = metadata[k]
         if len(v) > text_length_limit:
             v = v[:text_length_limit] + '...'
-        meta.append("%s = %s" % (k_shortenned, v))
+        meta.append("%s = %s" % (html_escape(k_shortenned), html_escape(v)))
     meta_str = "<br/>".join(meta)
-    if len(metadata.keys()) > meta_visible_limit:
+    if len(metadata.keys()) > meta_visible_limit and meta_str[-3:] != "...":
         meta_str += '...'
-    return meta_str
+    return mark_safe(meta_str)
 
 
 def get_nice_security_service_type(security_service):
@@ -91,3 +103,12 @@ def get_nice_security_service_type(security_service):
         'kerberos': 'Kerberos',
     }
     return type_mapping.get(security_service.type, security_service.type)
+
+
+def calculate_longest_str_size(str_list):
+    size = 40
+    for str_val in str_list:
+        current_size = len(str_val)
+        if current_size > size:
+            size = current_size
+    return size
